@@ -1,5 +1,5 @@
 # SystemC - SystemC Perl Interface
-# $Revision: #28 $$Date: 2004/08/12 $$Author: ws150726 $
+# $Revision: #30 $$Date: 2004/08/26 $$Author: ws150726 $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -26,7 +26,7 @@ use Verilog::Netlist::Subclass;
 use strict;
 use vars qw ($Debug $Default_Self $VERSION);
 
-$VERSION = '1.160';
+$VERSION = '1.161';
 
 structs('_new_base',
 	'SystemC::Template::Struct'
@@ -300,13 +300,22 @@ Adds to the out_text the given formatted text.
 
 =back
 
-=head1 SEE ALSO
+=head1 DISTRIBUTION
 
-L<SystemC::Netlist::File>
-L<Text::Template>
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 2001-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<SystemC::Netlist>,
+L<SystemC::Netlist::File>,
+L<Text::Template>
+
 =cut
